Crate poloto_chrono

Crate poloto_chrono 

Plot unix timestamps.

Does not implement dashes/grid lines because due to leap days, the distance between the dashes can’t be constant.

Structs

DynamicFormatter
Used by UnixTime::dynamic_format()
DynamicWhereFormatter
UnixTime
A 64 bit integer unix timestamp in seconds since the epoch in UTC.
UnixTimeFmt
UnixTimeTickFmt

Enums

StepUnit
Conveys what unit is being used for step sizes.

Functions

month_str
Returns a 3 letter string for a month. input must be in the range [1,12] or it will panic.